@@ -1,7 +1,7 @@
 use crate::*;
 
 /// Struct for the `background` modifier.
-pub struct Background<V: View, BG: View> {
+pub struct Background<V, BG> {
     child: V,
     background: BG,
 }
@@ -47,6 +47,22 @@ where
         self.child.commands(id.child(&0), cx, cmds);
         self.background.commands(id.child(&1), cx, cmds);
     }
+
+    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+        self.child.gc(id.child(&0), cx, map);
+        self.background.gc(id.child(&1), cx, map);
+    }
+
+    fn access(
+        &self,
+        id: ViewID,
+        cx: &mut Context,
+        nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        // XXX: if we were to create a node here, what role would it be?
+        //      could print a warning if there is an node produced by background.
+        self.child.access(id.child(&0), cx, nodes)
+    }
 }
 
 impl<V, BG> Background<V, BG>
@@ -58,3 +74,5 @@ where
         Self { child, background }
     }
 }
+
+impl<V, BG> private::Sealed for Background<V, BG> {}
