@@ -74,5 +74,18 @@ macro_rules! body_view {
         fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>) {
             self.body().commands(id, cx, cmds);
         }
+
+        fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+            self.body().gc(id, cx, map)
+        }
+
+        fn access(
+            &self,
+            id: ViewID,
+            cx: &mut Context,
+            nodes: &mut Vec<accesskit::Node>,
+        ) -> Option<accesskit::NodeId> {
+            self.body().access(id, cx, nodes)
+        }
     };
 }
