@@ -1,7 +1,7 @@
 use crate::*;
 
 /// Struct for `canvas`
-pub struct Canvas<F: Fn(LocalRect, &mut VGER)> {
+pub struct Canvas<F> {
     func: F,
 }
 
@@ -53,9 +53,22 @@ where
     }
 
     fn commands(&self, _id: ViewID, _cx: &mut Context, _cmds: &mut Vec<CommandInfo>) {}
+
+    fn gc(&self, _id: ViewID, _cx: &mut Context, _map: &mut StateMap) {}
+
+    fn access(
+        &self,
+        _id: ViewID,
+        _cx: &mut Context,
+        _nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        None
+    }
 }
 
-/// Canvas for GPU drawing with VGER. See https://github.com/audulus/vger-rs. Note that canvases cannot be hit tested and thus gestures cannot be attached.
-pub fn canvas<F: Fn(LocalRect, &mut VGER) + 'static>(f: F) -> Canvas<F> {
+/// Canvas for GPU drawing with VGER. See https://github.com/audulus/vger-rs.
+pub fn canvas<F: Fn(LocalRect, &mut VGER) + 'static>(f: F) -> impl View {
     Canvas { func: f }
 }
+
+impl<F> private::Sealed for Canvas<F> {}
