@@ -17,6 +17,7 @@ use std::hash::{Hash, Hasher};
 use std::sync::{Arc, Mutex};
 
 use tao::event_loop::EventLoopProxy;
+use tao::window::Window;
 
 /// `ViewID` is a unique identifier for a view. We're using a u64 and hashing
 /// under the assumption there won't be collsions. The underlying u64 is a function
@@ -39,12 +40,16 @@ impl ViewID {
             id: hasher.finish(),
         }
     }
+
+    pub fn access_id(&self) -> accesskit::NodeId {
+        accesskit::NodeId(std::num::NonZeroU64::new(self.id).unwrap())
+    }
 }
 
 pub const DEBUG_LAYOUT: bool = false;
 
 #[derive(Copy, Clone, Default, PartialEq, Debug)]
-pub struct LayoutBox {
+pub(crate) struct LayoutBox {
     pub rect: LocalRect,
     pub offset: LocalOffset,
 }
@@ -52,58 +57,73 @@ pub struct LayoutBox {
 // This could use a better name.
 pub struct Dirty {
     pub dirty: bool,
-    pub event_loop_proxy: Option<EventLoopProxy<()>>
+    pub event_loop_proxy: Option<EventLoopProxy<()>>,
 }
 
 impl Dirty {
     pub fn new(event_loop_proxy: Option<EventLoopProxy<()>>) -> Self {
-        Dirty{ dirty: false, event_loop_proxy }
+        Dirty {
+            dirty: false,
+            event_loop_proxy,
+        }
     }
 }
 
+/// Restricts what we can store in a StateMap (instead of just using Any)
+pub trait AnyState {
+    /// So we can downcast.
+    fn as_any(&self) -> &dyn Any;
+}
+
+pub type StateMap = HashMap<ViewID, Box<dyn AnyState>>;
+
 /// The Context stores all UI state. A user of the library
 /// shouldn't have to interact with it directly.
 pub struct Context {
     /// Map for `state`.
-    state_map: HashMap<ViewID, Box<dyn Any>>,
+    pub(crate) state_map: StateMap,
 
     /// Layout information for all views.
-    pub layout: HashMap<ViewID, LayoutBox>,
-
-    /// GPU renderer.
-    pub vger: Option<VGER>,
+    pub(crate) layout: HashMap<ViewID, LayoutBox>,
 
     /// Which views each touch (or mouse pointer) is interacting with.
-    pub touches: [ViewID; 16],
+    pub(crate) touches: [ViewID; 16],
 
     /// Points at which touches (or click-drags) started.
-    pub starts: [LocalPoint; 16],
+    pub(crate) starts: [LocalPoint; 16],
 
     /// Previous touch/mouse positions.
-    pub previous_position: [LocalPoint; 16],
+    pub(crate) previous_position: [LocalPoint; 16],
 
     /// The root view ID. This should be randomized for security reasons.
-    pub root_id: ViewID,
+    pub(crate) root_id: ViewID,
 
     /// The view that has the keybord focus.
-    pub focused_id: Option<ViewID>,
+    pub(crate) focused_id: Option<ViewID>,
 
     /// Did state change?
-    pub dirty: Arc<Mutex<Dirty>>,
+    pub(crate) dirty: Arc<Mutex<Dirty>>,
+
+    /// The tao window
+    pub(crate) window: Window,
+
+    /// The current title of the window
+    pub(crate) window_title: String,
 }
 
 impl Context {
-    pub fn new(event_loop_proxy: Option<EventLoopProxy<()>>) -> Self {
+    pub fn new(event_loop_proxy: Option<EventLoopProxy<()>>, window: Window) -> Self {
         Self {
             state_map: HashMap::new(),
             layout: HashMap::new(),
-            vger: None,
             touches: [ViewID::default(); 16],
             starts: [LocalPoint::zero(); 16],
             previous_position: [LocalPoint::zero(); 16],
             root_id: ViewID::default(),
             focused_id: None,
             dirty: Arc::new(Mutex::new(Dirty::new(event_loop_proxy))),
+            window,
+            window_title: "rui".into(),
         }
     }
 
@@ -119,7 +139,7 @@ impl Context {
             .entry(id)
             .or_insert_with(|| Box::new(State::new(default, d)));
 
-        if let Some(state) = s.downcast_ref::<State<S>>() {
+        if let Some(state) = s.as_any().downcast_ref::<State<S>>() {
             f(state.clone(), self)
         } else {
             panic!("state has wrong type")
@@ -138,18 +158,18 @@ impl Context {
             .entry(id)
             .or_insert_with(|| Box::new(State::new(default, d)));
 
-        if let Some(state) = s.downcast_ref::<State<S>>() {
+        if let Some(state) = s.as_any().downcast_ref::<State<S>>() {
             f(state.clone(), self)
         } else {
             panic!("state has wrong type")
         }
     }
 
-    pub fn with_state_vger<S: Clone + 'static, R, F: Fn(State<S>, &mut Self, &mut VGER) -> R>(
+    pub fn with_state_aux<S: Clone + 'static, T, R, F: Fn(State<S>, &mut Self, &mut T) -> R>(
         &mut self,
-        vger: &mut VGER,
         default: S,
         id: ViewID,
+        aux: &mut T,
         f: F,
     ) -> R {
         let d = self.dirty.clone();
@@ -158,8 +178,8 @@ impl Context {
             .entry(id)
             .or_insert_with(|| Box::new(State::new(default, d)));
 
-        if let Some(state) = s.downcast_ref::<State<S>>() {
-            f(state.clone(), self, vger)
+        if let Some(state) = s.as_any().downcast_ref::<State<S>>() {
+            f(state.clone(), self, aux)
         } else {
             panic!("state has wrong type")
         }
