@@ -1,7 +1,7 @@
 pub use crate::*;
 
 /// Struct for the `tap` gesture.
-pub struct Tap<V: View, F: Fn()> {
+pub struct Tap<V, F> {
     child: V,
     func: F,
 }
@@ -65,8 +65,23 @@ where
     fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>) {
         self.child.commands(id.child(&0), cx, cmds)
     }
+
+    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+        self.child.gc(id.child(&0), cx, map)
+    }
+
+    fn access(
+        &self,
+        id: ViewID,
+        cx: &mut Context,
+        nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        self.child.access(id.child(&0), cx, nodes)
+    }
 }
 
+impl<V, F> private::Sealed for Tap<V, F> {}
+
 pub enum GestureState {
     Began,
     Changed,
@@ -74,7 +89,7 @@ pub enum GestureState {
 }
 
 /// Struct for the `drag` gesture.
-pub struct Drag<V: View, F: Fn(LocalOffset, GestureState)> {
+pub struct Drag<V, F> {
     child: V,
     func: F,
 }
@@ -150,4 +165,19 @@ where
     fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>) {
         self.child.commands(id.child(&0), cx, cmds)
     }
+
+    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+        self.child.gc(id.child(&0), cx, map)
+    }
+
+    fn access(
+        &self,
+        id: ViewID,
+        cx: &mut Context,
+        nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        self.child.access(id.child(&0), cx, nodes)
+    }
 }
+
+impl<V, F> private::Sealed for Drag<V, F> {}
