@@ -1,7 +1,7 @@
 pub use crate::*;
 
 /// Struct for the `key` modifier.
-pub struct Key<V: View, F: Fn(KeyPress)> {
+pub struct Key<V, F> {
     child: V,
     func: F,
 }
@@ -55,4 +55,19 @@ where
     fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>) {
         self.child.commands(id.child(&0), cx, cmds)
     }
+
+    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+        self.child.gc(id.child(&0), cx, map)
+    }
+
+    fn access(
+        &self,
+        id: ViewID,
+        cx: &mut Context,
+        nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        self.child.access(id.child(&0), cx, nodes)
+    }
 }
+
+impl<V, F> private::Sealed for Key<V, F> {}
