@@ -87,6 +87,12 @@ pub use toggle::*;
 mod align;
 pub use align::*;
 
+mod role;
+pub use role::*;
+
+mod window;
+pub use window::*;
+
 use futures::executor::block_on;
 use std::collections::HashMap;
 use vger::color::*;
@@ -105,6 +111,11 @@ use tao::{
 
 use std::env;
 
+// See https://rust-lang.github.io/api-guidelines/future-proofing.html
+pub(crate) mod private {
+    pub trait Sealed {}
+}
+
 pub type KeyCode = tao::keyboard::KeyCode;
 pub type KeyPress = tao::keyboard::Key<'static>;
 
@@ -292,16 +303,19 @@ pub fn rui(view: impl View + 'static) {
     surface.configure(&device, &config);
 
     let mut vger = VGER::new(&device, wgpu::TextureFormat::Bgra8UnormSrgb);
-    let mut cx = Context::new(Some(event_loop.create_proxy()));
+    let mut cx = Context::new(Some(event_loop.create_proxy()), window);
     let mut mouse_position = LocalPoint::zero();
 
     let mut commands = Vec::new();
     view.commands(cx.root_id, &mut cx, &mut commands);
     let mut command_map = HashMap::new();
-    window.set_menu(Some(build_menubar(&commands, &mut command_map)));
+    cx.window
+        .set_menu(Some(build_menubar(&commands, &mut command_map)));
 
     let mut modifiers = ModifiersState::default();
 
+    let mut access_nodes = vec![];
+
     event_loop.run(move |event, _, control_flow| {
         // ControlFlow::Poll continuously runs the event loop, even if the OS hasn't
         // dispatched any events. This is ideal for games and similar applications.
@@ -333,10 +347,10 @@ pub fn rui(view: impl View + 'static) {
                 config.width = size.width.max(1);
                 config.height = size.height.max(1);
                 surface.configure(&device, &config);
-                window.request_redraw();
+                cx.window.request_redraw();
             }
             event::Event::UserEvent(_) => {
-                println!("received user event");
+                // println!("received user event");
             }
             event::Event::MainEventsCleared => {
                 // Application update code.
@@ -356,10 +370,34 @@ pub fn rui(view: impl View + 'static) {
                         commands = new_commands;
 
                         command_map.clear();
-                        window.set_menu(Some(build_menubar(&commands, &mut command_map)));
+                        cx.window
+                            .set_menu(Some(build_menubar(&commands, &mut command_map)));
                     }
 
-                    window.request_redraw();
+                    // Clean up state.
+                    let mut new_map = StateMap::new();
+                    view.gc(cx.root_id, &mut cx, &mut new_map);
+                    // println!("collected {} states", cx.state_map.len() - new_map.len());
+                    cx.state_map = new_map;
+
+                    // Get a new accesskit tree.
+                    let mut nodes = vec![];
+                    view.access(cx.root_id, &mut cx, &mut nodes);
+
+                    if nodes != access_nodes {
+                        println!("access nodes:");
+                        for node in &nodes {
+                            println!(
+                                "  id: {:?}, role: {:?}, children: {:?}",
+                                node.id, node.role, node.children
+                            );
+                        }
+                        access_nodes = nodes;
+                    } else {
+                        // println!("access nodes unchanged");
+                    }
+
+                    cx.window.request_redraw();
 
                     cx.dirty.lock().unwrap().dirty = false;
                 }
@@ -383,8 +421,8 @@ pub fn rui(view: impl View + 'static) {
                     }
                 };
 
-                let window_size = window.inner_size();
-                let scale = window.scale_factor() as f32;
+                let window_size = cx.window.inner_size();
+                let scale = cx.window.scale_factor() as f32;
                 // println!("window_size: {:?}", window_size);
                 let width = window_size.width as f32 / scale;
                 let height = window_size.height as f32 / scale;
@@ -441,7 +479,7 @@ pub fn rui(view: impl View + 'static) {
                 event: WindowEvent::CursorMoved { position, .. },
                 ..
             } => {
-                let scale = window.scale_factor() as f32;
+                let scale = cx.window.scale_factor() as f32;
                 mouse_position = [
                     position.x as f32 / scale,
                     (config.height as f32 - position.y as f32) / scale,
@@ -470,7 +508,7 @@ pub fn rui(view: impl View + 'static) {
                 ..
             } => {
                 modifiers = mods;
-                println!("modifiers changed: {:?}", modifiers);
+                // println!("modifiers changed: {:?}", modifiers);
             }
             event::Event::MenuEvent { menu_id, .. } => {
                 //println!("menu event");
@@ -493,16 +531,6 @@ pub fn rui(view: impl View + 'static) {
 mod tests {
 
     use super::*;
-    use std::sync::{Arc, Mutex};
-
-    #[test]
-    fn test_state_clone() {
-        let d = Arc::new(Mutex::new(Dirty::new(None)));
-        let s = State::new(0, d);
-        let s2 = s.clone();
-        s.set(42);
-        assert_eq!(s2.get(), 42);
-    }
 
     #[test]
     fn test_button() {
@@ -511,17 +539,12 @@ mod tests {
         });
     }
 
-    #[test]
-    fn test_state() {
-        let _ = state(0, |_s: State<usize>| EmptyView {});
-    }
-
-    #[test]
-    fn test_state2() {
-        let mut cx = Context::new(None);
-        let v = counter(42);
-        v.print(ViewID::default(), &mut cx);
-    }
+    // #[test]
+    // fn test_state2() {
+    //     let mut cx = Context::new(None);
+    //     let v = counter(42);
+    //     v.print(ViewID::default(), &mut cx);
+    // }
 
     fn counter(start: usize) -> impl View {
         state(start, |count: State<usize>| {
@@ -562,18 +585,4 @@ mod tests {
     fn test_binding() {
         let _ = state(42, |count: State<usize>| counter3(count));
     }
-
-    #[derive(Clone)]
-    struct BindingTestData {
-        x: usize,
-    }
-
-    #[test]
-    fn test_bind() {
-        let dirty = Arc::new(Mutex::new(Dirty::new(None)));
-        let s = State::new(BindingTestData { x: 0 }, dirty);
-        let b = bind!(s, x);
-        b.set(42);
-        assert_eq!(s.get().x, 42);
-    }
 }
