@@ -1,7 +1,7 @@
 use crate::*;
 
 /// Struct for the `padding` modifier.
-pub struct Padding<V: View> {
+pub struct Padding<V> {
     child: V,
     padding: f32,
 }
@@ -57,6 +57,19 @@ where
     fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>) {
         self.child.commands(id.child(&0), cx, cmds)
     }
+
+    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+        self.child.gc(id.child(&0), cx, map)
+    }
+
+    fn access(
+        &self,
+        id: ViewID,
+        cx: &mut Context,
+        nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        self.child.access(id.child(&0), cx, nodes)
+    }
 }
 
 pub enum PaddingParam {
@@ -89,3 +102,5 @@ where
         }
     }
 }
+
+impl<V> private::Sealed for Padding<V> {}
