@@ -65,8 +65,23 @@ impl View for Circle {
     fn commands(&self, _id: ViewID, _cx: &mut Context, _cmds: &mut Vec<CommandInfo>) {
         // do nothing
     }
+
+    fn gc(&self, _id: ViewID, _cx: &mut Context, _map: &mut StateMap) {
+        // do nothing
+    }
+
+    fn access(
+        &self,
+        _id: ViewID,
+        _cx: &mut Context,
+        _nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        None
+    }
 }
 
+impl private::Sealed for Circle {}
+
 /// Renders a circle which expands to fill available space.
 pub fn circle() -> Circle {
     Circle {
@@ -148,8 +163,23 @@ impl View for Rectangle {
     fn commands(&self, _id: ViewID, _cx: &mut Context, _cmds: &mut Vec<CommandInfo>) {
         // do nothing
     }
+
+    fn gc(&self, _id: ViewID, _cx: &mut Context, _map: &mut StateMap) {
+        // do nothing
+    }
+
+    fn access(
+        &self,
+        _id: ViewID,
+        _cx: &mut Context,
+        _nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        None
+    }
 }
 
+impl private::Sealed for Rectangle {}
+
 /// Renders a rectangle which expands to fill available space.
 pub fn rectangle() -> Rectangle {
     Rectangle {
