@@ -1,7 +1,7 @@
 use crate::*;
 
 /// Struct for the `size` modifier.
-pub struct Size<V: View> {
+pub struct Size<V> {
     child: V,
     size: LocalSize,
 }
@@ -42,8 +42,23 @@ where
     fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>) {
         self.child.commands(id.child(&0), cx, cmds)
     }
+
+    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+        self.child.gc(id.child(&0), cx, map)
+    }
+
+    fn access(
+        &self,
+        id: ViewID,
+        cx: &mut Context,
+        nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        self.child.access(id.child(&0), cx, nodes)
+    }
 }
 
+impl<V> private::Sealed for Size<V> {}
+
 impl<V> Size<V>
 where
     V: View + 'static,
