@@ -3,7 +3,7 @@ use crate::*;
 const SLIDER_WIDTH: f32 = 4.0;
 const SLIDER_THUMB_RADIUS: f32 = 10.0;
 
-pub struct HSlider<B: Binding<f32>> {
+pub struct HSlider<B> {
     value: B,
     thumb: Color,
 }
@@ -53,6 +53,7 @@ where
                 value.with_mut(|v| *v = (*v + off.x / w).clamp(0.0, 1.0));
             })
         })
+        .role(accesskit::Role::Slider)
     }
 
     pub fn thumb_color(self, thumb_color: Color) -> Self {
@@ -63,6 +64,8 @@ where
     }
 }
 
+impl<B> private::Sealed for HSlider<B> {}
+
 /// Horizontal slider built from other Views.
 pub fn hslider(value: impl Binding<f32>) -> HSlider<impl Binding<f32>> {
     HSlider {
@@ -71,7 +74,7 @@ pub fn hslider(value: impl Binding<f32>) -> HSlider<impl Binding<f32>> {
     }
 }
 
-pub struct VSlider<B: Binding<f32>> {
+pub struct VSlider<B> {
     value: B,
     thumb: Color,
 }
@@ -125,6 +128,8 @@ where
     }
 }
 
+impl<B> private::Sealed for VSlider<B> {}
+
 /// Horizontal slider built from other Views.
 pub fn vslider(value: impl Binding<f32>) -> VSlider<impl Binding<f32>> {
     VSlider {
