@@ -131,7 +131,7 @@ impl TextEditorState {
 }
 
 /// Struct for `text_editor`.
-pub struct TextEditor<B: Binding<String>> {
+pub struct TextEditor<B> {
     text: B,
 }
 
@@ -188,6 +188,8 @@ where
     body_view!();
 }
 
+impl<B> private::Sealed for TextEditor<B> {}
+
 pub fn text_editor(text: impl Binding<String>) -> impl View {
     TextEditor { text: text }
 }
